$RLDQN
========

An asynchronous deep Q-learning Network for training Game AI.


Look how easy it is to use:
------------------------------

    import dqn

    # Runing our model to train you own AI(The model will be saved in dictionary 'logs')
    
    dqn.run_dqn.run('Game Name')
    
    # Evaluating the effect of the model
    
    dqn.run_dqn.evaluate
    


You can see demos through download files.(Source file)

We provide several demos to show how to use these module in games.

And you can also see source code and demos on github.


Features
--------

- You do not need to know the algorithm.
- Make things faster
- Use the DQN to train games of yourself.


Installation
------------

Install RLDQN by running:

    pip install RLDQN

 
Contribute
----------

- Source Code: 

Support
-------

If you are having issues, please let us know.

We have a mailing list located at: 396032050@qq.com